summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/umlview.h
diff options
context:
space:
mode:
Diffstat (limited to 'umbrello/umbrello/umlview.h')
-rw-r--r--umbrello/umbrello/umlview.h108
1 files changed, 54 insertions, 54 deletions
diff --git a/umbrello/umbrello/umlview.h b/umbrello/umbrello/umlview.h
index 99a39198..0a74331f 100644
--- a/umbrello/umbrello/umlview.h
+++ b/umbrello/umbrello/umlview.h
@@ -18,8 +18,8 @@
// system includes
#include <kurl.h>
-#include <qdom.h>
-#include <qcanvas.h>
+#include <tqdom.h>
+#include <tqcanvas.h>
//local includes
#include "umlobjectlist.h"
@@ -49,15 +49,15 @@ class ToolBarStateFactory;
/**
* UMLView instances represent diagrams.
- * The UMLApp instance manages a QWidgetStack of UMLView instances.
+ * The UMLApp instance manages a TQWidgetStack of UMLView instances.
* The visible diagram is at the top of stack.
* The UMLView class inherits from QCanvasView and it owns the
* objects displayed on its related QCanvas (see m_WidgetList.)
*
* @author Paul Hensgen <phensgen@techie.com>
* Bugs and comments to uml-devel@lists.sf.net or http://bugs.kde.org
*/
-class UMLView : public QCanvasView {
+class UMLView : public TQCanvasView {
Q_OBJECT
public:
friend class UMLViewImageExporterModel;
@@ -91,26 +91,26 @@ public:
/**
* Return the documentation of the diagram.
*/
- QString getDoc() const {
+ TQString getDoc() const {
return m_Documentation;
}
/**
* Set the documentation of the diagram.
*/
- void setDoc( const QString &doc ) {
+ void setDoc( const TQString &doc ) {
m_Documentation = doc;
}
/**
* Return the name of the diagram.
*/
- QString getName() const;
+ TQString getName() const;
/**
* Set the name of the diagram.
*/
- void setName(const QString &name);
+ void setName(const TQString &name);
/**
* Returns the type of the diagram.
@@ -129,26 +129,26 @@ public:
/**
* Returns the fill color to use.
*/
- QColor getFillColor() const;
+ TQColor getFillColor() const;
/**
* Set the background color.
*
* @param color The color to use.
*/
- void setFillColor( const QColor &color );
+ void setFillColor( const TQColor &color );
/**
* Returns the line color to use.
*/
- QColor getLineColor() const;
+ TQColor getLineColor() const;
/**
* Sets the line color.
*
* @param color The color to use.
*/
- void setLineColor( const QColor &color );
+ void setLineColor( const TQColor &color );
/**
* Returns the line width to use.
@@ -287,12 +287,12 @@ public:
/**
* Returns the font to use
*/
- QFont getFont() const;
+ TQFont getFont() const;
/**
* Sets the font for the view and optionally all the widgets on the view.
*/
- void setFont(QFont font, bool changeAllWidgets = false);
+ void setFont(TQFont font, bool changeAllWidgets = false);
/**
* Returns whether to show operation signatures.
@@ -350,17 +350,17 @@ public:
/**
* contains the implementation for printing functionality
*/
- void print(KPrinter *pPrinter, QPainter & pPainter);
+ void print(KPrinter *pPrinter, TQPainter & pPainter);
/**
* Overrides the standard operation.
*/
- void hideEvent(QHideEvent *he);
+ void hideEvent(TQHideEvent *he);
/**
* Overrides the standard operation.
*/
- void showEvent(QShowEvent *se);
+ void showEvent(TQShowEvent *se);
/**
* Sees if a message is relevant to the given widget. If it does delete it.
@@ -411,7 +411,7 @@ public:
* @return Returns the widget found, returns 0 if no widget found.
*/
AssociationWidget * findAssocWidget(UMLWidget *pWidgetA,
- UMLWidget *pWidgetB, const QString& roleNameB);
+ UMLWidget *pWidgetB, const TQString& roleNameB);
/**
* Remove a widget from view.
@@ -426,7 +426,7 @@ public:
* @param w The widget to set to selected.
* @param me The mouse event containing the information about the selection.
*/
- void setSelected(UMLWidget * w, QMouseEvent * me);
+ void setSelected(UMLWidget * w, TQMouseEvent * me);
/**
* Clear the selected widgets list.
@@ -461,12 +461,12 @@ public:
/**
* Set the font for all the currently selected items.
*/
- void selectionSetFont( const QFont &font );
+ void selectionSetFont( const TQFont &font );
/**
* Set the line color for all the currently selected items.
*/
- void selectionSetLineColor( const QColor &color );
+ void selectionSetLineColor( const TQColor &color );
/**
* Set the line width for all the currently selected items.
@@ -476,7 +476,7 @@ public:
/**
* Set the fill color for all the currently selected items.
*/
- void selectionSetFillColor( const QColor &color );
+ void selectionSetFillColor( const TQColor &color );
/**
* Toggles the show setting sel of all selected items.
@@ -518,7 +518,7 @@ public:
/**
* Get the pos variable. Used internally to keep track of the cursor.
*/
- QPoint & getPos() {
+ TQPoint & getPos() {
return m_Pos;
}
@@ -527,7 +527,7 @@ public:
*
* @param _pos The position to set to.
*/
- void setPos(const QPoint &_pos) {
+ void setPos(const TQPoint &_pos) {
m_Pos = _pos;
}
@@ -654,17 +654,17 @@ public:
* @param rect the area of the diagram to copy
* @param diagram the class to store PNG picture of the paste operation.
*/
- void getDiagram(const QRect &rect, QPixmap & diagram);
+ void getDiagram(const TQRect &rect, TQPixmap & diagram);
/**
* Paint diagram to the paint device
*/
- void getDiagram(const QRect &area, QPainter & painter);
+ void getDiagram(const TQRect &area, TQPainter & painter);
/**
* Returns the PNG picture of the paste operation.
*/
- void copyAsImage(QPixmap*& pix);
+ void copyAsImage(TQPixmap*& pix);
/**
* Returns the imageExporter used to export the view.
@@ -697,7 +697,7 @@ public:
* Only call this straight after the event, the value won't stay valid.
* Should only be called by Assoc widgets at the moment. no one else needs it.
*/
- QPoint getPastePoint();
+ TQPoint getPastePoint();
/**
* Reset the paste point.
@@ -828,22 +828,22 @@ public:
/**
* Creates the "diagram" tag and fills it with the contents of the diagram.
*/
- virtual void saveToXMI( QDomDocument & qDoc, QDomElement & qElement );
+ virtual void saveToXMI( TQDomDocument & qDoc, TQDomElement & qElement );
/**
* Loads the "diagram" tag.
*/
- virtual bool loadFromXMI( QDomElement & qElement );
+ virtual bool loadFromXMI( TQDomElement & qElement );
/**
* Loads the "UISDiagram" tag of Unisys.IntegratePlus.2 generated files.
*/
- bool loadUISDiagram(QDomElement & qElement);
+ bool loadUISDiagram(TQDomElement & qElement);
/**
* Loads a "widget" element from XMI, used by loadFromXMI() and the clipboard.
*/
- UMLWidget* loadWidgetFromXMI(QDomElement& widgetElement);
+ UMLWidget* loadWidgetFromXMI(TQDomElement& widgetElement);
/**
* Add an object to the application, and update the view.
@@ -862,7 +862,7 @@ public:
* @return The widget thats line was clicked on.
* Returns 0 if no line was clicked on.
*/
- ObjectWidget * onWidgetLine( const QPoint &point );
+ ObjectWidget * onWidgetLine( const TQPoint &point );
/**
* Return pointer to the first selected widget (for multi-selection)
@@ -878,7 +878,7 @@ public:
* Returns NULL if the point is not inside any widget.
* Does not use or modify the m_pOnWidget member.
*/
- UMLWidget *getWidgetAt(const QPoint& p);
+ UMLWidget *getWidgetAt(const TQPoint& p);
/**
* Initialize and announce a newly created widget.
@@ -916,13 +916,13 @@ protected:
// Methods and members related to loading/saving
- bool loadWidgetsFromXMI( QDomElement & qElement );
+ bool loadWidgetsFromXMI( TQDomElement & qElement );
- bool loadMessagesFromXMI( QDomElement & qElement );
+ bool loadMessagesFromXMI( TQDomElement & qElement );
- bool loadAssociationsFromXMI( QDomElement & qElement );
+ bool loadAssociationsFromXMI( TQDomElement & qElement );
- bool loadUisDiagramPresentation(QDomElement & qElement);
+ bool loadUisDiagramPresentation(TQDomElement & qElement);
/**
* Contains the unique ID to allocate to a widget that needs an
@@ -943,12 +943,12 @@ protected:
/**
* The name of the diagram.
*/
- QString m_Name;
+ TQString m_Name;
/**
* The documentation of the diagram.
*/
- QString m_Documentation;
+ TQString m_Documentation;
/**
* Options used by view
@@ -1017,17 +1017,17 @@ protected:
/**
* Override standard method.
*/
- void closeEvent ( QCloseEvent * e );
+ void closeEvent ( TQCloseEvent * e );
/**
* Override standard method.
*/
- void contentsDragEnterEvent(QDragEnterEvent* mouseEvent);
+ void contentsDragEnterEvent(TQDragEnterEvent* mouseEvent);
/**
* Override standard method.
*/
- void contentsDropEvent(QDropEvent* mouseEvent);
+ void contentsDropEvent(TQDropEvent* mouseEvent);
/**
@@ -1035,7 +1035,7 @@ protected:
*
* @return Returns the smallest area to print.
*/
- QRect getDiagramRect();
+ TQRect getDiagramRect();
/**
@@ -1047,25 +1047,25 @@ protected:
* Overrides the standard operation.
* Calls the same method in the current tool bar state.
*/
- void contentsMouseReleaseEvent(QMouseEvent* mouseEvent);
+ void contentsMouseReleaseEvent(TQMouseEvent* mouseEvent);
/**
* Overrides the standard operation.
* Calls the same method in the current tool bar state.
*/
- void contentsMouseMoveEvent(QMouseEvent* mouseEvent);
+ void contentsMouseMoveEvent(TQMouseEvent* mouseEvent);
/**
* Override standard method.
* Calls the same method in the current tool bar state.
*/
- void contentsMouseDoubleClickEvent(QMouseEvent* mouseEvent);
+ void contentsMouseDoubleClickEvent(TQMouseEvent* mouseEvent);
/**
* Override standard method.
* Calls the same method in the current tool bar state.
*/
- void contentsMousePressEvent(QMouseEvent* mouseEvent);
+ void contentsMousePressEvent(TQMouseEvent* mouseEvent);
/**
@@ -1106,14 +1106,14 @@ protected:
void findMaxBoundingRectangle(const FloatingTextWidget* ft,
int& px, int& py, int& qx, int& qy);
- void forceUpdateWidgetFontMetrics(QPainter *painter);
+ void forceUpdateWidgetFontMetrics(TQPainter *painter);
/**
* Used for creating unique name of collaboration messages.
*/
int m_nCollaborationId;
- QPoint m_Pos;
+ TQPoint m_Pos;
bool m_bCreateObject, m_bDrawSelectedOnly, m_bPaste;
ListPopupMenu * m_pMenu;
UMLWidgetList m_SelectedList;
@@ -1159,7 +1159,7 @@ private:
/**
* The offset at which to paste the clipboard.
*/
- QPoint m_PastePoint;
+ TQPoint m_PastePoint;
/**
* Pointer to the UMLDoc
@@ -1226,7 +1226,7 @@ public slots:
void slotShowView();
/**
- * Overrides standard method from QWidget to resize canvas when
+ * Overrides standard method from TQWidget to resize canvas when
* it's shown.
*/
void show();
@@ -49,15 +49,15 @@ class ToolBarStateFactory;
* The visible diagram is at the top of stack.
- * The UMLView class inherits from QCanvasView and it owns the
- * objects displayed on its related QCanvas (see m_WidgetList.)
+ * The UMLView class inherits from TQCanvasView and it owns the
+ * objects displayed on its related TQCanvas (see m_WidgetList.)
*
* @author Paul Hensgen <phensgen@techie.com>